package Google::Cloud::Orchestration::Airflow::Service::V1::ImageVersions;

use strict;
use warnings;

our $VERSION = '0.11';

use Protobuf::Message;
use Protobuf::DescriptorPool;
use Protobuf::Internal qw(:all);
use MIME::Base64;

BEGIN {
    eval { require Google::Api::Annotations };
    eval { require Google::Api::Client };
    eval { require Google::Type::Date };
    my $descriptor_b64 = <<'EOF';

b3RvMw==
EOF
    Protobuf::DescriptorPool->generated_pool->add_serialized_file(MIME::Base64::decode_base64($descriptor_b64));
}

# Message definitions

# === Message: Google::Cloud::Orchestration::Airflow::Service::V1::ImageVersions::ListImageVersionsRequest ===
    # Fields for ListImageVersionsRequest
    # Field: parent Type: 9 ()
    # Field: page_size Type: 5 ()
    # Field: page_token Type: 9 ()
    # Field: include_past_releases Type: 8 ()

=pod

=head1 NAME

Google::Cloud::Orchestration::Airflow::Service::V1::ImageVersions::ListImageVersionsRequest - Compiled Protocol Buffers message class

=head1 SYNOPSIS

    use Google::Cloud::Orchestration::Airflow::Service::V1::ImageVersions;

    my $msg = Google::Cloud::Orchestration::Airflow::Service::V1::ImageVersions::ListImageVersionsRequest->new(
        parent => $value,
    );

=head1 FIELDS

=over 4

=item * B<parent>

Type: String

=item * B<page_size>

Type: Int32

=item * B<page_token>

Type: String

=item * B<include_past_releases>

Type: Bool

=back

=cut

# === Message: Google::Cloud::Orchestration::Airflow::Service::V1::ImageVersions::ListImageVersionsResponse ===
    # Fields for ListImageVersionsResponse
    # Field: image_versions Type: 11 (.google.cloud.orchestration.airflow.service.v1.ImageVersion)
    # Field: next_page_token Type: 9 ()

=pod

=head1 NAME

Google::Cloud::Orchestration::Airflow::Service::V1::ImageVersions::ListImageVersionsResponse - Compiled Protocol Buffers message class

=head1 SYNOPSIS

    use Google::Cloud::Orchestration::Airflow::Service::V1::ImageVersions;

    my $msg = Google::Cloud::Orchestration::Airflow::Service::V1::ImageVersions::ListImageVersionsResponse->new(
        image_versions => $value,
    );

=head1 FIELDS

=over 4

=item * B<image_versions>

Type: Message (.google.cloud.orchestration.airflow.service.v1.ImageVersion)

=item * B<next_page_token>

Type: String

=back

=cut

# === Message: Google::Cloud::Orchestration::Airflow::Service::V1::ImageVersions::ImageVersion ===
    # Fields for ImageVersion
    # Field: image_version_id Type: 9 ()
    # Field: is_default Type: 8 ()
    # Field: supported_python_versions Type: 9 ()
    # Field: release_date Type: 11 (.google.type.Date)
    # Field: creation_disabled Type: 8 ()
    # Field: upgrade_disabled Type: 8 ()

=pod

=head1 NAME

Google::Cloud::Orchestration::Airflow::Service::V1::ImageVersions::ImageVersion - Compiled Protocol Buffers message class

=head1 SYNOPSIS

    use Google::Cloud::Orchestration::Airflow::Service::V1::ImageVersions;

    my $msg = Google::Cloud::Orchestration::Airflow::Service::V1::ImageVersions::ImageVersion->new(
        image_version_id => $value,
    );

=head1 FIELDS

=over 4

=item * B<image_version_id>

Type: String

=item * B<is_default>

Type: Bool

=item * B<supported_python_versions>

Type: String

=item * B<release_date>

Type: Message (.google.type.Date)

=item * B<creation_disabled>

Type: Bool

=item * B<upgrade_disabled>

Type: Bool

=back

=cut

# === Service Client: Google::Cloud::Orchestration::Airflow::Service::V1::ImageVersions::ImageVersionsClient ===
package Google::Cloud::Orchestration::Airflow::Service::V1::ImageVersions::ImageVersionsClient;

=pod

=head1 NAME

Google::Cloud::Orchestration::Airflow::Service::V1::ImageVersions::ImageVersionsClient - Client stub representing the remote ImageVersions service

=head1 DESCRIPTION

This class acts as a local client stub for the remote gRPC service.
It delegates call dispatching to an underlying L<Google::gRPC::Client>
instance, ensuring type-safe request parsing and response mapping.

=head1 CONFIGURATION AND ENVIRONMENT

=head2 target

The endpoint target address. Defaults to C<orchestration.googleapis.com:443>.

=head2 credentials

The authentication credentials provider. Defaults to application default credentials via L<Google::Auth>.

=cut

use Moo;
use Google::Auth;
use Google::gRPC::Client;

has credentials => ( is => 'ro', default => sub { Google::Auth->default() } );
has target      => ( is => 'ro', default => 'orchestration.googleapis.com:443' );

has _grpc_client => (
    is => 'ro',
    lazy => 1,
    builder => sub {
        my $self = shift;
        return Google::gRPC::Client->new(
            target     => $self->target,
            auth_token => $self->credentials->get_token(),
        );
    }
);

sub list_image_versions {
    my ($self, $args) = @_;
    my $req = ref($args) eq 'HASH'
        ? Google::Cloud::Orchestration::Airflow::Service::V1::ImageVersions::ListImageVersionsRequest->new($args)
        : $args;
    return $self->_grpc_client->call({
        service        => 'google.cloud.orchestration.airflow.service.v1.ImageVersions',
        method         => 'ListImageVersions',
        request        => $req,
        response_class => 'Google::Cloud::Orchestration::Airflow::Service::V1::ImageVersions::ListImageVersionsResponse',
    });
}

1;

__END__

=head1 NAME

Google::Cloud::Orchestration::Airflow::Service::V1::ImageVersions - Protocol Buffers schema definition

=head1 DESCRIPTION

Auto-generated Protocol Buffers schema definition class.

=head1 LICENSE AND COPYRIGHT

Copyright (C) 2026 Google LLC

This program is released under the Apache 2.0 license.

=cut
